<?php
/**
 * Plugin Name: Full screen preloader
 * Description: A powerful plugin to show full screen preloader with 8 different predefined spinner style and background color option 
 * Version: 1.0.2
 * Author: Vidya LB
 * Author URI: http://vidyalb.com
 * License: GPL
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
// if direct access.
if ( ! class_exists( 'FSPL_Preloader' ) ) {
	/**
	 * FSPL_Preloader main class
	 * author : Vidya
	 */
	class FSPL_Preloader {
		/**
		 * Plugin settings.
		 */
		private $settings;
		/**
		 * FSPL_Preloader constructor
		 */
		public function __construct() {
			$this->settings = array(
				'plugin_path'       => plugin_dir_path( __FILE__ ),
				'plugin_url'        => plugin_dir_url( __FILE__ ),
				'plugin_base'       => dirname( plugin_basename( __FILE__ ) ),
				'plugin_file'       => __FILE__,
				'plugin_version'    => '1.0.0',
			);
			$this->fspl_load_plugin_textdomain();
			$this->fspl_init();
		}
		/**
		 * Localisation
		 */
		public function fspl_load_plugin_textdomain() {
			load_plugin_textdomain( 'full-screen-loader', false, $this->settings['plugin_base'] . '/language/' );
		}
		/**
		 * Plugin main functions
		 *
		 * @since: 1.0.0
		 */
		public function fspl_init() {
			add_action( 'wp_enqueue_scripts', array( $this, 'fspl_shortcode_wp_enqueue_scripts' ) );
			add_action( 'wp_footer', array( $this, 'fspl_preloader_class' ), 10, 1 );
			add_action( 'admin_menu', array( $this, 'fspl_preloader_settings_menu' ) );
			add_action( 'admin_enqueue_scripts', array( $this, 'fspl_admin_script' ) );
			add_action( 'admin_init', array( $this, 'fspl_save_form_option' ) );
		}
		/**
		 * Register preloader scripts and styles
		 *
		 * @since: 1.0.0
		 */
		public function fspl_shortcode_wp_enqueue_scripts() {
			wp_register_script( 'fspl-min-script', plugins_url( 'js/fakeLoader.min.js', $this->settings['plugin_file'] ), array( 'jquery' ), $this->settings['plugin_version'], false );
			wp_register_script( 'fspl-script', plugins_url( 'js/fspl-preloader.js', $this->settings['plugin_file'] ), array( 'jquery', 'fspl-min-script' ), $this->settings['plugin_version'], true );
			wp_register_style( 'fspl-style', plugins_url( 'css/fakeLoader.css', $this->settings['plugin_file'] ), false, $this->settings['plugin_version'], 'all' );
			wp_enqueue_script( 'fspl-min-script' );

			$option_array = array(
				'bg_color' => get_option( 'fspl_bg_color' ),
				'style' => get_option( 'fspl_style' ),
				'custom_image' => esc_url( get_option( 'fspl_image' ) ),
			);
			wp_enqueue_script( 'fspl-min-script' );
			wp_localize_script( 'fspl-script', 'fspl_obj', $option_array );
			wp_enqueue_script( 'fspl-script' );
			wp_enqueue_style( 'fspl-style' );
		}
		/**
		 * Register preloader admin scripts and styles
		 *
		 * @since: 1.0.0
		 */
		public function fspl_admin_script() {
			wp_enqueue_media();
			wp_register_script( 'fspl-admin-script', plugins_url( 'js/fspl-admin.js', $this->settings['plugin_file'] ), array( 'jquery', 'iris' ), $this->settings['plugin_version'], true );
			wp_enqueue_script( 'fspl-admin-script' );
			wp_register_style( 'fspl-admin-style', plugins_url( 'css/admin.css', $this->settings['plugin_file'] ), false, $this->settings['plugin_version'], 'all' );
			wp_enqueue_style( 'fspl-admin-style' );
		}
		/**
		 * Add custom class to post classes array
		 *
		 * @param HTML $content - the html content.
		 * @since: 1.0.0
		 */
		public function fspl_preloader_class( ) {
			echo '<div class="fspl-overlay"><div class="fsPreloader">Loading....</div></div>';
		}

		/**
		 * Add submenu under settings
		 *
		 * @since: 1.0.0
		 */
		public function fspl_preloader_settings_menu() {
			add_submenu_page(
				'options-general.php',
				'Full Screen Preloader',
				'Full Screen Preloader',
				'manage_options',
				'full-screen-preloader',
				array( $this, 'fspl_render_preloader_settings' )
			);
		}
		/**
		 * Render preloader settings form
		 *
		 * @since 1.0.0
		 */
		public function fspl_render_preloader_settings() { ?>
			<div class="wrap">
				<h1 class="wp-heading-inline"><?php esc_html_e( 'Full screen preloader settings' ); ?></h1>
				<form name="fspl-form" method="post">
					<?php wp_nonce_field( 'fspl_settings_nonce', 'settings_nonce' ); ?>
					<div class="fspl-form-field">
						<label for="fspl_bg_color"><?php esc_html_e( 'Background Color' ); ?></label><input type="text" name="fspl_bg_color" id="fspl_bg_color" value="<?php echo esc_attr( get_option( 'fspl_bg_color' ) ); ?>" >
					</div>
					<div class="fspl-form-field">
						<label for="fspl_style"><?php esc_html_e( 'Spinner style' ); ?></label>
						<?php echo $this->spinner_style(); ?>
					
					<!-- <div class="fspl-form-field"> -->
						<?php $visibility = ( get_option( 'fspl_style' ) == '8' ) ? 'display: block' : 'display: none'; ?>
						<div class="fspl_image_link" style="<?php echo esc_attr( $visibility ); ?>">
							<?php
							$upload_link = esc_url( get_option( 'fspl_image' ) );
							?>
							<label for="fspl_link_image">Enter custom image URL</label><input type="text" name="fspl_link_image" id="fspl_link_image" size="75" value="<?php echo $upload_link; ?>"> or 
							<p class="hide-if-no-js">
								<a id="upload-btn" href="javascript:void(0)"> <?php _e( 'Set custom image' ); ?> </a>
							</p>
						<!-- </div> -->
					</div>
						
					</div>
					<p><input type="submit" value="save" class="button button-primary" name="fspl_save_options"></p>
				</form>
			</div>
			<?php
		}
		/**
		 * Display preloader styles
		 *
		 * @since 1.0.0
		 */
		public function spinner_style() {
			$style = '';
			for ( $i = 1; $i <= 8; $i++ ) {
				if ( $i == 8 ) {
					$label = 'Custom image';
				} else {
					$label = 'Style ' . $i;
				}
				$style .= "<div class='fieldgroup'><input type='radio' value=$i name='fspl_style' " . checked( get_option( 'fspl_style' ), $i, false ) . "> <label for='fspl_style'> " . $label . " </label></div>";
			}
			return $style;
		}
		/**
		 * Save global plugin options
		 *
		 * @since 1.0.0
		 */
		public function fspl_save_form_option() {
			// verify nonce.
			if ( ! empty( $_POST['fspl_save_options'] ) && check_admin_referer( 'fspl_settings_nonce', 'settings_nonce' ) ) {
				$bg_color = sanitize_text_field( $_POST['fspl_bg_color'] );
				$style = sanitize_text_field( $_POST['fspl_style'] );
				$image = sanitize_text_field( $_POST['fspl_link_image'] );
				update_option( 'fspl_bg_color', $bg_color );
				update_option( 'fspl_style', $style );
				update_option( 'fspl_image', $image );
			}
		}
	}
	new FSPL_Preloader();
}
